@@ -60,7 +60,7 @@ Rest_engraver::do_process_requests ()
 	  String reststyle = get_property ("restStyle", 0);
 	  if (reststyle.length_i ())
 	    rest_p_->set_elt_property (style_scm_sym,
-				       gh_str02scm (reststyle.ch_C()));
+				       ly_ch_C_to_scm (reststyle.ch_C()));
 	}
       announce_element (Score_element_info (rest_p_, rest_req_l_));
     }
